@@ -347,6 +347,11 @@ class Appliance:  # pylint: disable=too-many-public-methods
         """Return True if the device has humidity sensor."""
         return False
 
+    @property
+    def support_advanced_modes(self):
+        """Return True if the device supports advanced modes."""
+        return 'adv' in self.values
+
     @property
     def support_energy_consumption(self):
         """Return True if the device supports energy consumption monitoring."""
@@ -480,6 +485,10 @@ class Appliance:  # pylint: disable=too-many-public-methods
         """Set holiday mode."""
         raise NotImplementedError
 
+    async def set_advanced_mode(self, mode, value):
+        """Enable or disable advanced modes."""
+        raise NotImplementedError
+
     @property
     def zones(self):
         """Return list of zones."""
