@@ -32,6 +32,16 @@ class DaikinBRP069(Appliance):
         },
         'f_dir': {'0': 'off', '1': 'vertical', '2': 'horizontal', '3': '3d',},
         'en_hol': {'0': 'off', '1': 'on',},
+        'adv': {
+            '': 'off',
+            '2': 'powerful',
+            '2/13': 'powerful streamer',
+            '12': 'econo',
+            '12/13': 'econo streamer',
+            '13': 'streamer',
+        },
+        'spmode_kind': {'0': 'streamer', '1': 'powerful', '2': 'econo',},
+        'spmode': {'0': 'off', '1': 'on',},
     }
 
     HTTP_RESOURCES = [
@@ -69,6 +79,7 @@ class DaikinBRP069(Appliance):
         'en_hol',
         'err',
         'cur',
+        'adv',
     ]
 
     VALUES_TRANSLATION = {
@@ -83,6 +94,7 @@ class DaikinBRP069(Appliance):
         'err': 'error code',
         'en_hol': 'away_mode',
         'cur': 'internal clock',
+        'adv': 'advanced mode',
     }
 
     async def init(self):
@@ -152,6 +164,19 @@ class DaikinBRP069(Appliance):
             _LOGGER.debug("Sending query: %s", query_h)
             await self._get_resource(query_h)
 
+    async def set_advanced_mode(self, mode, value):
+        """Enable or disable advanced modes."""
+        mode = self.human_to_daikin('spmode_kind', mode)
+        value = self.human_to_daikin('spmode', value)
+        if value in ('0', '1'):
+            query_h = 'aircon/set_special_mode?spmode_kind=%s&set_spmode=%s' % (
+                mode,
+                value,
+            )
+            _LOGGER.debug("Sending query: %s", query_h)
+            # Update the adv value from the response
+            self.values.update(await self._get_resource(query_h))
+
     async def set_zone(self, zone_id, status):
         """Set zone status."""
 
